function [ Global ] = CHEMICAL_REACTION( Global )
%CHEMICAL_REACTION Calculate compostion after pre-combustion
%   This function use the combustion efficency to calculate composition of
%   the gas in the combustion rig after pre-combustion

%Combustion efficiency, first inital value and later runs based on the
%two-zone calculations
eta_comb = Global.eta_comb(Global.s);

% Number of moles in the mix of gas and air
nO2 = Global.mO2mix/Global.MO2;
nCO = Global.mCOmix/Global.MCO;
nN2 = Global.mN2mix/Global.MN2;
nH2 = Global.mH2mix/Global.MH2;

% Reactants
Global.nO2r = nO2;
Global.nCOr = nCO;
Global.nN2r = nN2;
Global.nH2r = nH2;

% Molar fractions of the reactants
Global.yO2r = nO2/(nO2+nCO+nN2+nH2);
Global.yCOr = nCO/(nO2+nCO+nN2+nH2);
Global.yN2r = nN2/(nO2+nCO+nN2+nH2);
Global.yH2r = nH2/(nO2+nCO+nN2+nH2);

% Calculate the products
for i = 1:length(eta_comb)
    
    % Number of moles
    Global.nO2p(i) = nO2 - 0.5*eta_comb(i)*(nCO+nH2);
    Global.nN2p = nN2;
    Global.nCO2p(i) = eta_comb(i) * nCO;
    Global.nH2Op(i) = eta_comb(i) * nH2;
    Global.nH2p(i) = (1-eta_comb(i)) * nH2;
    Global.nCOp(i) = (1-eta_comb(i)) * nCO;
    
    % Mole fractions
    Global.yO2p(i) = Global.nO2p(i) / (Global.nO2p(i) + Global.nN2p ...
    + Global.nCO2p(i) + Global.nCOp(i) + Global.nH2p(i) + Global.nH2Op(i));
    Global.yN2p = Global.nN2p / (Global.nO2p(i) + Global.nN2p ...
    + Global.nCO2p(i) + Global.nCOp(i) + Global.nH2p(i) + Global.nH2Op(i));
    Global.yCOp(i) = Global.nCOp(i) / (Global.nO2p(i) + Global.nN2p ...
    + Global.nCO2p(i) + Global.nCOp(i) + Global.nH2p(i) + Global.nH2Op(i));
    Global.yCO2p(i) = Global.nCO2p(i) / (Global.nO2p(i) + Global.nN2p ...
    + Global.nCO2p(i) + Global.nCOp(i) + Global.nH2p(i) + Global.nH2Op(i));
    Global.yH2p(i) = Global.nH2p(i) / (Global.nO2p(i) + Global.nN2p ...
    + Global.nCO2p(i) + Global.nCOp(i) + Global.nH2p(i) + Global.nH2Op(i));
    Global.yH2Op(i) = Global.nH2Op(i) / (Global.nO2p(i) + Global.nN2p ...
    + Global.nCO2p(i) + Global.nCOp(i) + Global.nH2p(i) + Global.nH2Op(i));
    
    % Mass fractions
    Global.xO2p(i) = Global.yO2p(i)*Global.MO2/...
        (Global.yO2p(i)*Global.MO2...
        + Global.yN2p*Global.MN2 + Global.yCOp(i)*Global.MCO...
        + Global.yCO2p(i)*Global.MCO2 + Global.yH2p(i)*Global.MH2...
        + Global.yH2Op(i)*Global.MH2O);
    Global.xN2p = Global.yN2p*Global.MN2/(Global.yO2p(i)*Global.MO2 + ...
        Global.yN2p*Global.MN2 + Global.yCOp(i)*Global.MCO + ...
        Global.yCO2p(i)*Global.MCO2 + Global.yH2p(i)*Global.MH2...
        + Global.yH2Op(i)*Global.MH2O);
    Global.xCOp(i) = Global.yCOp(i)*Global.MCO/...
        (Global.yO2p(i)*Global.MO2 + Global.yN2p*Global.MN2...
        + Global.yCOp(i)*Global.MCO + Global.yCO2p(i)*Global.MCO2...
        + Global.yH2p(i)*Global.MH2 + Global.yH2Op(i)*Global.MH2O);
    Global.xCO2p(i) = Global.yCO2p(i)*Global.MCO2/...
        (Global.yO2p(i)*Global.MO2 + Global.yN2p*Global.MN2...
        + Global.yCOp(i)*Global.MCO + Global.yCO2p(i)*Global.MCO2...
        + Global.yH2p(i)*Global.MH2 + Global.yH2Op(i)*Global.MH2O);
    Global.xH2p(i) = Global.yH2p(i)*Global.MH2/...
        (Global.yO2p(i)*Global.MO2 + Global.yN2p*Global.MN2...
        + Global.yCOp(i)*Global.MCO + Global.yCO2p(i)*Global.MCO2...
        + Global.yH2p(i)*Global.MH2 + Global.yH2Op(i)*Global.MH2O);
    Global.xH2Op(i) = Global.yH2Op(i)*Global.MH2O/...
    (Global.yO2p(i)*Global.MO2 + Global.yN2p*Global.MN2...
    + Global.yCOp(i)*Global.MCO + Global.yCO2p(i)*Global.MCO2...
    + Global.yH2p(i)*Global.MH2 + Global.yH2Op(i)*Global.MH2O);

    % Resulting gas constant
    Global.Rburned(i) = Global.RO2 .* Global.xO2p(i) + ...
    Global.RN2 * Global.xN2p + ...
    Global.RCO * Global.xCOp(i) + ...
    Global.RCO2 * Global.xCO2p(i) ...
    + Global.RH2 * Global.xH2p(i) ...
    + Global.RH2O * Global.xH2Op(i);
end
end