% Run file to initate all parameters and calculations

function Global  = RUN(Global)

% Load measurements, calculate absolute pressure and fractions of each gas
% at start of experiment
[ Global ] = CONSTANTS(Global);

% Calculate resulting composition after pre-combustion with the initial
% combustion efficency
[ Global ] = CHEMICAL_REACTION( Global );

% Calculate the heat loss coefficent based on gas constant after
% pre-combustion and pressure drop from pre-combustion ends to injection
% starts
[ Global ] = HEAT_LOSS_COEFFICIENT( Global );

% Solve the two-zone model
[ Global ] = TWO_ZONES( Global );


% If the values for combustion efficency and/or temperature difference
% between the two-model solution and chemical reaction, the calculations
% are performed again with PI-controller to the temp-difference.
while ((abs((Global.eta_comb(Global.s+1)...
        -Global.eta_comb(Global.s)))>0.01) ...
        ||(abs(Global.T_diff(end))>5)) && Global.s<25
    
[ Global ] = CHEMICAL_REACTION( Global );

[ Global ] = HEAT_LOSS_COEFFICIENT( Global );

 Global.s = Global.s+1;

[ Global ] = TWO_ZONES( Global );

end

% If while loop stops by maximum number of runs, calculate composition for
% eta_comb = 0.95 and display the resulting values
if Global.s == 25;
    
    Global.eta_comb = 0.95;
    Global.s = 1;
    
    [ Global ] = CONSTANTS(Global);

    [ Global ] = CHEMICAL_REACTION( Global );

    [ Global ] = HEAT_LOSS_COEFFICIENT( Global );

    [ Global ] = TWO_ZONES( Global );
    
end

% Rate of heat release calculated for pre-cobustion and injection
% experiment
[ Global ] = ROHR( Global );

% Print calculated values to text-file
OUTPUT( Global )