function [ zone1, zone2 ] = ZONES_DATA( Global )
%ZONES_DATA Calculates the mass fraction of each gas
%   This function calculates the mass fraction of each gas in zone 1 and 
%   zone 2 to determine the thermodynamic state of the entire zone based 
%   on the thermodynaic state of each substance

nO2 = (Global.mrig * Global.xO2mix)/Global.MO2;
nCO = (Global.mrig * Global.xCOmix)/Global.MCO;
nN2 = (Global.mrig * Global.xN2mix)/Global.MN2;
nH2 = (Global.mrig * Global.xH2mix)/Global.MH2;

% Composition of zone 1 expressed in mass fractions
zone1.xCO = Global.xCOmix;
zone1.xN2 = Global.xN2mix;
zone1.xO2 = Global.xO2mix;
zone1.xH2 = Global.xH2mix;
zone1.xCO2 = 0;
zone1.xH2O = 0;

% Compostion of zone 2 expressed in mass fractions
zone2.nO2 = nO2-0.5*(nCO+nH2);
zone2.nN2 = nN2;
zone2.nCO2 = nCO;
zone2.nH2O = nH2;
zone2.yO2 = zone2.nO2/(zone2.nO2+zone2.nN2+zone2.nCO2+zone2.nH2O);
zone2.yN2 = zone2.nN2/(zone2.nO2+zone2.nN2+zone2.nCO2+zone2.nH2O);
zone2.yCO2 = zone2.nCO2/(zone2.nO2+zone2.nN2+zone2.nCO2+zone2.nH2O);
zone2.yH2O = zone2.nH2O/(zone2.nO2+zone2.nN2+zone2.nCO2+zone2.nH2O);
zone2.xO2 = zone2.yO2*Global.MO2/(zone2.yO2*Global.MO2 + ...
    zone2.yN2*Global.MN2 + zone2.yCO2*Global.MCO2);
zone2.xN2 = zone2.yN2*Global.MN2/(zone2.yO2*Global.MO2 + ...
    zone2.yN2*Global.MN2 + zone2.yCO2*Global.MCO2);
zone2.xCO2 = zone2.yCO2*Global.MCO2/(zone2.yO2*Global.MO2 + ...
    zone2.yN2*Global.MN2 + zone2.yCO2*Global.MCO2);
zone2.xCO = 0;
zone2.xH2 = 0;
zone2.xH2O = zone2.yH2O*Global.MH2O/(zone2.yO2*Global.MO2 + ...
   zone2.yN2*Global.MN2 + zone2.yCO2*Global.MCO2);

end

